import discord
from discord.ext import commands
import os

PREFIX = ("?", "!")
TOKEN = os.environ.get("DISCORD_BOT_SECRET")
initial_extensions = ["cogs.base", "cogs.dice", "cogs.quote"]


def get_prefix(bot, message):
    prefixes = ["?", "!"]

    if not message.guild:
        return "?"

    return commands.when_mentioned_or(*prefixes)(bot, message)


def run():
    bot = commands.Bot(command_prefix=get_prefix, description="Erky")

    for extension in initial_extensions:
        try:
            bot.load_extension(extension)
        except commands.errors.ExtensionNotFound:
            bot.load_extension("sprocket." + extension)

    @bot.event
    async def on_ready():
        await bot.change_presence(activity=discord.Game(name="With Himself"))
        print("Logged in as")
        print(bot.user.name)
        print(bot.user.id)
        print("------")

    bot.run(TOKEN, bot=True, reconnect=True)


if __name__ == "__main__":
    run()



from discord.ext import commands


class Base(commands.Cog):
    def __init__(self, bot):
        self.bot = bot

    @commands.command(name="me")
    @commands.is_owner()
    async def only(self, ctx):
        await ctx.send(f"Hello {ctx.author.mention}")

    @commands.command(name="hello")
    async def hello(self, ctx):
        await ctx.send(f"Hello {ctx.author.mention}")


def setup(bot):
    bot.add_cog(Base(bot))



import os


class Loader:
    def __init__(self):
        self.success = False

    def __bool__(self):
        return self.success

    def load(self, filename):
        filepath = os.path.join(os.path.dirname(__file__), filename)
        try:
            self.raw = open(filepath, "r").read()
            self.success = True
        except FileNotFoundError:
            self.success = False
            print("File not found")



from discord.ext import commands
from sprocket.data.loader import Loader
import random


class Quote(commands.Cog):
    def __init__(self, bot):
        self.bot = bot
        self.files = ["13th-warrior.txt", "lotr.txt", "baldursgate.txt"]
        self.Loader = Loader()
        self.quotes = []
        self.read_files()

    @commands.command(name="speak", aliases=["say", "s"])
    async def speak(self, ctx):
        quote = random.choice(self.quotes)
        await ctx.send("```fix\n{0}```".format(quote))

    def read_files(self):
        for file in self.files:
            self.Loader.load(file)
            if self.Loader:
                strings = self.Loader.raw.split("\n\n")
                self.quotes += strings


def setup(bot):
    bot.add_cog(Quote(bot))



from dicey.dieparser import DieParser
from discord.ext import commands
from lark import exceptions


class Dice(commands.Cog):
    def __init__(self, bot):
        self.bot = bot
        self.dieparser = DieParser()
        self.user_rolls = {}

    def _cycle_user_list(self, key):
        while len(self.user_rolls[key]) > 10:
            self.user_rolls[key] = self.user_rolls[key][1:]

    def _eval_expr(self, expr):
        self.dieparser.parse(expr)
        return self.dieparser.__str__()

    @commands.command(name="roll", aliases=["r"])
    async def roll(self, ctx, *args):
        expr = " ".join(args)

        try:
            result = self._eval_expr(expr)
        except exceptions.UnexpectedCharacters:
            msg = "invalid expression\n"
            msg += "```yaml\nexample: 1d20 + 2d4 -1 + 1d6 + 2```"
            print("lark.exceptions.UnexpectedCharacters caught")
            await ctx.send(msg)
            return

        self.user_rolls.setdefault(ctx.author.id, []).append(expr)
        self._cycle_user_list(ctx.author.id)

        await ctx.send("```yaml\n{0}```".format(result))

    @commands.group(
        aliases=["rr"], pass_context=True, invoke_without_command=True
    )
    async def reroll(self, ctx):
        if ctx.invoked_subcommand is None:
            if ctx.author.id in self.user_rolls:
                expr = self.user_rolls[ctx.author.id][-1]
                result = self._eval_expr(expr)
                await ctx.send("```yaml\n{0}```".format(result))

    @reroll.group(
        aliases=["l"], pass_context=True, invoke_without_command=True
    )
    async def list(self, ctx):
        roll_history = "```yaml\n"
        if ctx.author.id in self.user_rolls:
            for i, roll in enumerate(self.user_rolls[ctx.author.id]):
                roll_history += "{0} : {1}\n".format(i + 1, roll)
            roll_history += "```"
            await ctx.send(roll_history)
        else:
            await ctx.send("roll history empty")

    @reroll.group(
        aliases=["1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        pass_context=True,
    )
    async def selection(self, ctx, *args):
        selection = [
            int(s) for s in ctx.message.content.split() if s.isdigit()
        ][0]
        result = self._eval_expr(self.user_rolls[ctx.author.id][selection - 1])
        await ctx.send("```yaml\n{0}```".format(result))


def setup(bot):
    bot.add_cog(Dice(bot))



from discord.ext import commands
import os

PREFIX = ("?", "!")
TOKEN = os.environ.get("DISCORD_BOT_SECRET")
initial_extensions = ["cogs.base", "cogs.dice"]


def get_prefix(bot, message):
    prefixes = ["?", "!"]

    if not message.guild:
        return "?"

    return commands.when_mentioned_or(*prefixes)(bot, message)
